@@ -20,6 +20,7 @@ from .extensible_serial_instrument import (
 
 import re
 import logging
+import semantic_version
 
 
 class Sangaboard(ExtensibleSerialInstrument):
@@ -46,7 +47,7 @@ class Sangaboard(ExtensibleSerialInstrument):
     """
 
     # List of valid and deprecated firmwares, for communication checks
-    valid_firmwares = [(0, 5), (0, 4)]
+    valid_firmwares = [(1,0), (0, 5), (0, 4)]
     deprecated_firmwares = [(0, 4)]
 
     # These are the settings for the sangaboards serial port, and can usually be left as default.
@@ -134,6 +135,12 @@ class Sangaboard(ExtensibleSerialInstrument):
                     )
 
             self.board = self.query("board", timeout=2).rstrip()
+            if self.version_tuple[0] == 1:
+                # Enable v0.5-compatible behaviour on newer firmware
+                logging.info("Enabling backwards-compatible behaviour on new Sangaboard firmware")
+                self.query("blocking_moves True")
+            else:
+                print("version was pre-1.0", self.parsed_firmware_version)
 
         except Exception as e:
             # If an error occurred while setting up (e.g. because the board isn't connected or something)
@@ -161,29 +168,32 @@ class Sangaboard(ExtensibleSerialInstrument):
             logging.warning("No firmware version string was returned.")
             return False
         logging.info("Firmware response: {}".format(self.firmware))
-        # Check for valid firmware string. Regexes in order are
-        # * 3-element semantic version + prerelease
-        # * 3-element semantic version
-        # * 2-element version, present on v0.5 and earlier
-        # * Old firmware <0.4
-        for version_regex in [
-            r"Sangaboard Firmware v(([\d]+)\.([\d]+)\.([\d]+)-(\S+))\s*$",
-            r"Sangaboard Firmware v(([\d]+)\.([\d]+)\.([\d]+))\s*$",
-            r"Sangaboard Firmware v(([\d]+)\.([\d]+))\s*$",
-            r"OpenFlexure Motor Board v(([\d]+)\.([\d]+))\s*$",
-            ]:
-            match = re.match(version_regex, self.firmware)
-            if match:
-                break
+        # Check for valid firmware string. Version group is matched later with semantic_version
+        match = re.match(
+            r"(Sangaboard Firmware|OpenFlexure Motor Board) v(.*)\s*$", 
+            self.firmware
+        )
         if not match:
             logging.warning(
-                'Version string "{}" was not recognised as a supported version. '
-                'It should be 0.4 or 0.5.x.'.format(self.firmware)
+                f'Version string "{self.firmware}" was not recognised as a supported version.'
             )
             return False
-
-        self.firmware_version = match.group(1)
-        self.version_tuple = (int(match.group(2)), int(match.group(3)) if match.group(3) else None)
+        self.firmware_version = match.group(2)
+        try:
+            # We use "coerce" to allow two-element versions from old firmware
+            # otherwise "0.5" is not a valid version string.
+            parsed_version = semantic_version.Version.coerce(self.firmware_version)
+            self.parsed_firmware_version = parsed_version
+        except ValueError as v:
+            logging.warning(
+                f'Could not parse version string "{self.firmware_version}" as a semantic version.'
+            )
+            return False
+        self.version_tuple = (parsed_version.major, parsed_version.minor)
+        if parsed_version.prerelease:
+            logging.warning(
+                f'You are using a Sangaboard with prerelease firmware "{self.firmware_version}"'
+            )
 
         if self.version_tuple not in Sangaboard.valid_firmwares:
             logging.warning(
@@ -368,7 +378,7 @@ class Endstops(OptionalModule):
         if "y" in axes:
             ax += 2
         if "z" in axes:
-            ax += 3
+            ax += 4
 
         if direction == "min" or direction == "both":
             self._parent.query("home_min {}".format(ax))
